This function modifies the input data frame such that the names of every column are in snake case. Internally, it uses the to_snake_case.

all_columns_to_snakecase(x)

Arguments

x

The input data frame.

Examples

x <- data.frame(notSnakecase = 1:10)
all_columns_to_snakecase(x)
#>    not_snakecase
#> 1              1
#> 2              2
#> 3              3
#> 4              4
#> 5              5
#> 6              6
#> 7              7
#> 8              8
#> 9              9
#> 10            10