Get object versions from an aws s3 bucket recursively
get_versions_list(bucket_name, key_marker = "", prefix = "")Name of the bucket to connect. By default, it uses the Ministry for the Environment data lake for environmental reporting "mfedlkinput".
The key marker from which to download the object metadata.
The prefix from which to download the object metadata. Empty string download all metadata
a list with metadata