A function used to round numbers using the IEC 60559 standard. base::round doesn't always behave in this manner (see help round for more information). This function is designed to mask base::round.

round(x, digits)

Arguments

x

metric. A vector

digits

an integer indicating the number of decimal places to be used.

Value

a vector rounded to the digits specified.