#' Performs the Sen's slope trend test. This function is a wrapper around sens.slope. See documentation there for more details about the calculation

sen_slope(x, conf_level = 0.95)

Arguments

x

numeric vector or a time series object of class "ts"

conf_level

confidence level of the test

Value

a tidy data frame with the test results

Examples

x <- runif(100) * 1:100
sen_slope(x)
#> # A tibble: 1 × 9
#>    p_value slope conf_low conf_high conf_level     z method          n note 
#>      <dbl> <dbl>    <dbl>     <dbl>      <dbl> <dbl> <chr>       <int> <chr>
#> 1 4.23e-10 0.464    0.330     0.594       0.95  6.25 Sen's slope   100 NA