This function set ups the credentials required to access an AWS S3 bucket programatically. By default it connects to the Environmental Reporting Data Lake.
setup_datalake_access(
cred_csv = "~/credentials.csv",
bucket_name = mfe_datalake_bucket
)A csv file with the credentials information. At a minimum it
should have two columns: "Access key ID" and "Secret access key". By
default setup_datalake_access looks for this file in the user
directory "~/credentials.csv".
Name of the bucket to connect. By default, it uses the Ministry for the Environment data lake for environmental reporting "mfedlkinput".
if (FALSE) { # \dontrun{
setup_datalake_access(cred_csv = "~/credentials.csv", bucket_name = "mfedlkinput")
} # }