Table to metadata Adds attributes to df object and returns and prints list of attributes

table_to_metadata(df, metadata)

Arguments

df

dataframe object

metadata

attribute names and values to be added to df object

retain_row_names

Logical. defaults to FALSE (row.names attribute will be removed), set to TRUE if row.names attribute to be retained

Value

list of attribute names and values