R/datalake.R
write_rds_datalake.RdWrite an RDS file to the lake. .RDS so the attributes can be saved as metadata. Basic attributes are applied below But you can add your own using attr(). V The function first writes the file to a temp directory therefore, it avoids the unintended consequences of saving the file in the disk.
write_rds_datalake(data, s3_path)if (FALSE) { # \dontrun{
setup_datalake_access()
read_from_datalake("landcover", "concordance", "lcdb4")
} # }