R/datalake.R
table_to_metadata.Rd
Table to metadata Adds attributes to df object and returns and prints list of attributes
table_to_metadata(df, metadata)
dataframe object
attribute names and values to be added to df object
Logical. defaults to FALSE (row.names attribute will be removed), set to TRUE if row.names attribute to be retained
list of attribute names and values